# Changelog

## [0.1.1] - 2026-03-05

Maintenance release.

- Drop support for Python 3.10

## [0.1.0] - 2026-02-05

Maintenance release.

- Support Python3.10-3.13 (#256)
- Add explicit pins for Zarr<3

## [0.0.3] - 2025-06-11

- Fix missing matplib dependency (#249)

- Pin panel to fix missing mutations plot (#250)


## [0.0.2] - 2024-12-09

- Remove populations plot (#240)


## [0.0.1] - 2024-11-18

Initial release of tsbrowse.
